@@ -7,30 +7,29 @@
 
 import time
 import unittest
+
+from domonic.dom import *
+from domonic.html import *
+
+import domonic.d3 as d3
 # import requests
 # from mock import patch
 # from domonic.javascript import Math
 from domonic import domonic
-
-from domonic.dom import *
-from domonic.html import *
 from domonic.d3 import *
-
-from domonic.svg import *
-from domonic.d3.path import Path
+from domonic.d3.dispatch import Dispatch, dispatch
 from domonic.d3.format import *
 from domonic.d3.format import format
-
-from domonic.d3.dispatch import dispatch, Dispatch
-
-# from domonic.d3.polygon import *
-# from domonic.d3.timer import *
-
+from domonic.d3.path import Path
 from domonic.d3.selection import *
 from domonic.decorators import silence
 
 
-import domonic.d3 as d3
+# from domonic.d3.polygon import *
+# from domonic.d3.timer import *
+
+from domonic.svg import *  # lowercase path is in here
+
 
 
 class TestCase(unittest.TestCase):
@@ -1095,6 +1094,7 @@ class TestCase(unittest.TestCase):
     def test_append(self):
 
         from domonic.dom import document
+
         # from domonic.dom import document  # remember to bring in document explicitly as it's a global
         # print(document)
         d = html(body("Hello"))
@@ -1104,7 +1104,8 @@ class TestCase(unittest.TestCase):
         print('body', d.doctype)
         print('bodyx', domonic.dom.document.doctype)
         print('body', document.doctype)
-        from domonic.dom import document  # re-import to get the updated document
+        from domonic.dom import \
+            document  # re-import to get the updated document
         print('body', document.doctype)
         assert type(select(document.body).append("h1")) == Selection
 
